==> blesta-5.10.2.zip: blesta/components/modules/direct_admin/language/es_es/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.es_es
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.!error.server_name.empty'] = 'Debe introducir una Etiqueta de servidor.';
$lang['DirectAdmin.!error.host_name.format'] = 'El nombre del host no es válido.';
$lang['DirectAdmin.!error.port.format'] = 'El puerto debe ser un número.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Debe introducir un nombre de usuario.';
$lang['DirectAdmin.!error.password.format'] = 'Debe introducir una Contraseña.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Usar SSL debe ser verdadero o falso.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'El Límite de cuenta debe dejarse en blanco (para cuentas ilimitadas) o establecerse en algún valor entero.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Uno o varios de los servidores de nombres introducidos no son válidos.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Debe definir al menos 2 servidores de nombres.';
$lang['DirectAdmin.!error.api.internal'] = 'Se ha producido un error interno o el servidor no ha respondido a la solicitud.';
$lang['DirectAdmin.!error.meta[type].format'] = 'El tipo de cuenta debe ser usuario o revendedor.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Se requiere un paquete DirectAdmin.';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Se requiere una dirección IP.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Introduzca un nombre de dominio válido del tipo: dominio.com';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'El nombre de usuario sólo puede contener caracteres alfanuméricos.';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'El nombre de usuario debe tener entre 4 y 8 caracteres.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Asegúrese de que la contraseña contiene lo siguiente: Al menos 12 caracteres, al menos 1 carácter en mayúscula A-Z, al menos 1 carácter en minúscula a-z, al menos 1 número 0-9 y al menos 1 carácter especial del conjunto: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'La contraseña y la contraseña de confirmación no coinciden.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Introduzca una dirección de correo electrónico válida.';
$lang['DirectAdmin.!error.change_package.type'] = 'El módulo no permite cambiar entre paquetes de usuario y de revendedor.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.description'] = 'DirectAdmin es un panel de control gráfico de alojamiento web diseñado para facilitar la administración de sitios web.';
$lang['DirectAdmin.module_row'] = 'Servidor';
$lang['DirectAdmin.module_row_plural'] = 'Servidores';
$lang['DirectAdmin.module_group'] = 'Grupo de servidores';
$lang['DirectAdmin.tab_stats'] = 'Estadísticas';
$lang['DirectAdmin.tab_client_actions'] = 'Acciones';
$lang['DirectAdmin.order_options.first'] = 'Primer servidor no lleno';
$lang['DirectAdmin.order_options.roundrobin'] = 'Distribución uniforme entre servidores';
$lang['DirectAdmin.servers.no_results'] = 'No hay servidores.';
$lang['DirectAdmin.server_groups.no_results'] = 'No hay grupos de servidores.';
$lang['DirectAdmin.service_field.domain'] = 'Dominio';
$lang['DirectAdmin.service_field.username'] = 'Nombre de usuario';
$lang['DirectAdmin.service_field.password'] = 'Contraseña';
$lang['DirectAdmin.service_field.email'] = 'Correo electrónico';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Generar contraseña';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Cambiar contraseña';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Contraseña';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Confirmar contraseña';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Actualizar contraseña';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Generar contraseña';
$lang['DirectAdmin.service_info.username'] = 'Nombre de usuario';
$lang['DirectAdmin.service_info.password'] = 'Contraseña';
$lang['DirectAdmin.service_info.server'] = 'Servidor';
$lang['DirectAdmin.service_info.options'] = 'Opciones';
$lang['DirectAdmin.service_info.option_login'] = 'Conectarse';
$lang['DirectAdmin.package_fields.type'] = 'Tipo de cuenta';
$lang['DirectAdmin.package_fields.type_user'] = 'Usuario';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Revendedor';
$lang['DirectAdmin.package_fields.package'] = 'Paquete DirectAdmin';
$lang['DirectAdmin.package_fields.ip'] = 'Dirección IP';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Compartido';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Asignar';
$lang['DirectAdmin.add_module_row'] = 'Añadir servidor';
$lang['DirectAdmin.add_module_group'] = 'Añadir grupo de servidores';
$lang['DirectAdmin.manage.module_rows_title'] = 'Servidores';
$lang['DirectAdmin.manage.module_groups_title'] = 'Grupos de servidores';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Etiqueta del servidor';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Nombre del host';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Cuentas';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Opciones';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Nombre del grupo';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Recuento de servidores';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Opciones';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Editar';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Editar';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Borrar';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Borrar';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = '¿Está seguro de que desea eliminar este servidor?';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = '¿Está seguro de que desea eliminar este grupo de servidores?';
$lang['DirectAdmin.row_meta.server_name'] = 'Etiqueta del servidor';
$lang['DirectAdmin.row_meta.host_name'] = 'Nombre del host';
$lang['DirectAdmin.row_meta.port'] = 'Puerto';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.user_name'] = 'Nombre de usuario';
$lang['DirectAdmin.row_meta.password'] = 'Contraseña';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Utilice SSL al conectarse a la API (recomendado)';
$lang['DirectAdmin.row_meta.account_limit'] = 'Límite de la cuenta';
$lang['DirectAdmin.row_meta.name_server'] = 'Servidor de nombres %1$s';
$lang['DirectAdmin.add_row.box_title'] = 'Añadir servidor DirectAdmin';
$lang['DirectAdmin.add_row.basic_title'] = 'Configuración básica';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Servidores de nombres';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Añadir servidor de nombres adicional';
$lang['DirectAdmin.add_row.name_server_col'] = 'Servidor de nombres';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Nombre de host';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Eliminar';
$lang['DirectAdmin.add_row.notes_title'] = 'Notas';
$lang['DirectAdmin.add_row.add_btn'] = 'Añadir servidor';
$lang['DirectAdmin.edit_row.box_title'] = 'Editar servidor DirectAdmin';
$lang['DirectAdmin.edit_row.basic_title'] = 'Configuración básica';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Servidores de nombres';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Añadir servidor de nombres adicional';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Servidor de nombres';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Nombre de host';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Eliminar';
$lang['DirectAdmin.edit_row.notes_title'] = 'Notas';
$lang['DirectAdmin.edit_row.add_btn'] = 'Editar servidor';
$lang['DirectAdmin.tab_client_stats'] = 'Estadísticas';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Información';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Campo';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Valor';
$lang['DirectAdmin.tab_client_stats.no_results'] = 'Actualmente no se dispone de información estadística.';

==> blesta-5.11.4.zip: blesta/components/modules/direct_admin/language/es_es/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.es_es
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.!error.server_name.empty'] = 'Debe introducir una Etiqueta de servidor.';
$lang['DirectAdmin.!error.host_name.format'] = 'El nombre del host no es válido.';
$lang['DirectAdmin.!error.port.format'] = 'El puerto debe ser un número.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Debe introducir un nombre de usuario.';
$lang['DirectAdmin.!error.password.format'] = 'Debe introducir una Contraseña.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Usar SSL debe ser verdadero o falso.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'El Límite de cuenta debe dejarse en blanco (para cuentas ilimitadas) o establecerse en algún valor entero.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Uno o varios de los servidores de nombres introducidos no son válidos.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Debe definir al menos 2 servidores de nombres.';
$lang['DirectAdmin.!error.api.internal'] = 'Se ha producido un error interno o el servidor no ha respondido a la solicitud.';
$lang['DirectAdmin.!error.meta[type].format'] = 'El tipo de cuenta debe ser usuario o revendedor.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Se requiere un paquete DirectAdmin.';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Se requiere una dirección IP.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Introduzca un nombre de dominio válido del tipo: dominio.com';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'El nombre de usuario sólo puede contener caracteres alfanuméricos.';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'El nombre de usuario debe tener entre 4 y 8 caracteres.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Asegúrese de que la contraseña contiene lo siguiente: Al menos 12 caracteres, al menos 1 carácter en mayúscula A-Z, al menos 1 carácter en minúscula a-z, al menos 1 número 0-9 y al menos 1 carácter especial del conjunto: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'La contraseña y la contraseña de confirmación no coinciden.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Introduzca una dirección de correo electrónico válida.';
$lang['DirectAdmin.!error.change_package.type'] = 'El módulo no permite cambiar entre paquetes de usuario y de revendedor.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.description'] = 'DirectAdmin es un panel de control gráfico de alojamiento web diseñado para facilitar la administración de sitios web.';
$lang['DirectAdmin.module_row'] = 'Servidor';
$lang['DirectAdmin.module_row_plural'] = 'Servidores';
$lang['DirectAdmin.module_group'] = 'Grupo de servidores';
$lang['DirectAdmin.tab_stats'] = 'Estadísticas';
$lang['DirectAdmin.tab_client_actions'] = 'Acciones';
$lang['DirectAdmin.order_options.first'] = 'Primer servidor no lleno';
$lang['DirectAdmin.order_options.roundrobin'] = 'Distribución uniforme entre servidores';
$lang['DirectAdmin.servers.no_results'] = 'No hay servidores.';
$lang['DirectAdmin.server_groups.no_results'] = 'No hay grupos de servidores.';
$lang['DirectAdmin.service_field.domain'] = 'Dominio';
$lang['DirectAdmin.service_field.username'] = 'Nombre de usuario';
$lang['DirectAdmin.service_field.password'] = 'Contraseña';
$lang['DirectAdmin.service_field.email'] = 'Correo electrónico';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Generar contraseña';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Cambiar contraseña';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Contraseña';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Confirmar contraseña';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Actualizar contraseña';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Generar contraseña';
$lang['DirectAdmin.service_info.username'] = 'Nombre de usuario';
$lang['DirectAdmin.service_info.password'] = 'Contraseña';
$lang['DirectAdmin.service_info.server'] = 'Servidor';
$lang['DirectAdmin.service_info.options'] = 'Opciones';
$lang['DirectAdmin.service_info.option_login'] = 'Conectarse';
$lang['DirectAdmin.package_fields.type'] = 'Tipo de cuenta';
$lang['DirectAdmin.package_fields.type_user'] = 'Usuario';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Revendedor';
$lang['DirectAdmin.package_fields.package'] = 'Paquete DirectAdmin';
$lang['DirectAdmin.package_fields.ip'] = 'Dirección IP';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Compartido';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Asignar';
$lang['DirectAdmin.add_module_row'] = 'Añadir servidor';
$lang['DirectAdmin.add_module_group'] = 'Añadir grupo de servidores';
$lang['DirectAdmin.manage.module_rows_title'] = 'Servidores';
$lang['DirectAdmin.manage.module_groups_title'] = 'Grupos de servidores';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Etiqueta del servidor';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Nombre del host';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Cuentas';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Opciones';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Nombre del grupo';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Recuento de servidores';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Opciones';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Editar';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Editar';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Borrar';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Borrar';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = '¿Está seguro de que desea eliminar este servidor?';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = '¿Está seguro de que desea eliminar este grupo de servidores?';
$lang['DirectAdmin.row_meta.server_name'] = 'Etiqueta del servidor';
$lang['DirectAdmin.row_meta.host_name'] = 'Nombre del host';
$lang['DirectAdmin.row_meta.port'] = 'Puerto';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.user_name'] = 'Nombre de usuario';
$lang['DirectAdmin.row_meta.password'] = 'Contraseña';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Utilice SSL al conectarse a la API (recomendado)';
$lang['DirectAdmin.row_meta.account_limit'] = 'Límite de la cuenta';
$lang['DirectAdmin.row_meta.name_server'] = 'Servidor de nombres %1$s';
$lang['DirectAdmin.add_row.box_title'] = 'Añadir servidor DirectAdmin';
$lang['DirectAdmin.add_row.basic_title'] = 'Configuración básica';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Servidores de nombres';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Añadir servidor de nombres adicional';
$lang['DirectAdmin.add_row.name_server_col'] = 'Servidor de nombres';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Nombre de host';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Eliminar';
$lang['DirectAdmin.add_row.notes_title'] = 'Notas';
$lang['DirectAdmin.add_row.add_btn'] = 'Añadir servidor';
$lang['DirectAdmin.edit_row.box_title'] = 'Editar servidor DirectAdmin';
$lang['DirectAdmin.edit_row.basic_title'] = 'Configuración básica';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Servidores de nombres';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Añadir servidor de nombres adicional';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Servidor de nombres';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Nombre de host';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Eliminar';
$lang['DirectAdmin.edit_row.notes_title'] = 'Notas';
$lang['DirectAdmin.edit_row.add_btn'] = 'Editar servidor';
$lang['DirectAdmin.tab_client_stats'] = 'Estadísticas';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Información';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Campo';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Valor';
$lang['DirectAdmin.tab_client_stats.no_results'] = 'Actualmente no se dispone de información estadística.';
$lang['DirectAdmin.row_meta.ip_address'] = 'Dirección IP';
$lang['DirectAdmin.!error.ip_address.format'] = 'La dirección IP parece no ser válida.';
